var MobileShell = {
    version: "0.0.1",
    messageCount: 0,
    embeddedAppInfo: "",
    promiseCallbacks: [],
    constants: {
        KEYWORD_CALLBACKID: "callbackID",
        KEYWORD_COMMAND: "command",
        KEYWORD_CATEGORY: "category",
        KEYWORD_PAYLOAD: "payload"
    }
};

MobileShell.messageNative = function(msg) {
    var callbackID = "cb" + MobileShell.messageCount;
    MobileShell.messageCount++;

    msg.callbackID = callbackID;

    var promise = new Promise(function(resolve, reject) {
        var callback = {
            callbackID: callbackID,
            resolve: function(value) {
                delete MobileShell.promiseCallbacks[callbackID];
                resolve(value);
            },
            reject: function(value) {
                delete MobileShell.promiseCallbacks[callbackID];
                reject(value);
            }
        };

        MobileShell.promiseCallbacks[callbackID] = callback;

        if (typeof(JSBridge) !== "undefined") {
            JSBridge.msgToNative(JSON.stringify(msg));
        } else {
            callback.reject({
                errorNum: 999,
                msg: "Lost JSBridge instance while sending msg: " + JSON.stringify(msg)
            });
        }
    });

    return promise;
}

MobileShell.completePromise = function(data) {
    var callbackID = data.callbackID;
    var payload = data.payload;
    var verb = data.verb;

    var cb = MobileShell.promiseCallback(callbackID);

    if (typeof cb != 'undefined') {
        if (verb == 'resolve') {
            cb.resolve(payload);
        } else {
            cb.reject(payload);
        }
    }
};

MobileShell.promiseCallback = function(callbackID) {
    return MobileShell.promiseCallbacks[callbackID];
};

MobileShell.callPromiseFunction = function(promiseInvocation) {
    var functionCallStr = promiseInvocation.functionCallStr;
    var promiseCallbackID = promiseInvocation.promiseCallbackID;
    var invalidFunctionCallError = {
        category: "promise",
        command: "reject",
        payload: {
            promiseCallbackID: promiseCallbackID,
            reason: "Invalid function call"
        }
    };

    if (typeof functionCallStr !== "string") {
        MobileShell.messageNative(invalidFunctionCallError);

        return;
    }

    var promise = null;

    try {
        promise = eval(functionCallStr);
    } catch (e) {
        invalidFunctionCallError.payload.reason = e;
        MobileShell.messageNative(invalidFunctionCallError);

        return;
    }

    if (!(typeof promise === "object" || typeof promise === "function") || !('then' in promise) || typeof(promise.then) !== "function") {
        MobileShell.messageNative(invalidFunctionCallError);

        return;
    }

    var message = {
        category: "promise",
        payload: {
            promiseCallbackID: promiseCallbackID
        }
    };

    var onResolve = function (result) {
        message.command = "resolve";
        message.payload.result = result;

        MobileShell.messageNative(message);
    };

    var onReject = function (reason) {
        message.command = "reject";
        message.payload.reason = reason;

        MobileShell.messageNative(message);
    }

    promise.then(onResolve, onReject);
};

MobileShell.testJSPromise = function(url) {
    console.log("About to get data from: " + url);

    return new Promise(function(resolve, reject) {
        var req = new XMLHttpRequest();

        req.onload = function() {
            if (req.status === 200) {
                resolve(req.response);
            }
            else {
                reject(req.statusText);
            }
        };
        req.onerror = function() {
            reject("Network Error");
        };

        req.open('GET', url);
        req.send();
    });
};

MobileShell.setEmbeddedAppInfo = function(embeddedAppInfo) {
    MobileShell.embeddedAppInfo = embeddedAppInfo
    console.log("MobileShell.setEmbeddedAppInfo");
};
