PonHelp = {
    showUI : function (helpContent, shouldEmbedIntoTemplate) {

        if(shouldEmbedIntoTemplate) {
            // Embed the html
            this.embedHelpContent(helpContent);
        } else {
            // no need to embed; just customize the UI
            this.customizeHelpContent();
        }
        
        // Add handlers for hyperlinks so that we can route it back to native code
        var hrefTags = document.getElementsByTagName('a');
        for(var i = 0; i < hrefTags.length; i++) {
            
            var link = hrefTags[i];
            // Apply style to link (TTO's javascript replaces <a href=""> with <button class="ponHyperButton">)
            link.className = link.className + " ponHyperButton";
            
            // Hide link 'Back to Top'
            if(link.text.toLowerCase() == 'back to top') {
                link.style.display = 'none';
            }
            link.onclick = function(){
                var matches = new RegExp("hyperTo\\('(.*)'\\).*").exec(this.href)
                if(matches != null && matches.length > 0) {
                    window.location = 'ttu://externalLink?helpLinkId=' + encodeURIComponent(matches[1]);
                    return;
                }
                var matches = new RegExp("hyperToUrl\\('(.*)'\\).*").exec(link)
                if(matches != null && matches.length > 0) {
                    window.location = 'ttu://externalLink?URL=' + encodeURIComponent(matches[1]);
                    return;
                }
            }
        }
    },
    
    embedHelpContent: function (helpContent){
        // Embed the help content in the current view
        // Parse the helpContent and format it so suit TTU style
        // Note: Use non-greedy search so that it will match the first matching pair of <H1>..</H1>; instead of first <H1> and last </H1>
        var contentParsingRegex = "<TITLE>(.*)<\/TITLE>.*<BODY.*?>(<H1>.*?<\/H1>)(.*)<\/BODY>";
        var matches = new RegExp(contentParsingRegex).exec(helpContent);
        if(matches != null && matches.length > 2) {
            // This is regular TTO Pon content; so read the title and put on top, hide the H1 and take just the main content
            
            // First, add the title
            var title = matches[1];
            
            // Add the main content
            if(matches.length == 3) {
                // regex has only two matching parts (i.e. TITLE and BODY only); no H1. Take the <BODY...> part in the main section
                document.getElementById('ponHeadline').innerText = title;
                document.getElementById('ponMainWindow').innerHTML = matches[2];
                
            } else {
                // regex has all 3 parts (TITLE, H1 and BODY)
                //   If there is only H1, hide the H1 part (the title would anyway be displayed in H1 style).
                //   If there are multiple H1s (as in 1099-MISC), then we have to show all of them (so we will combine H1 part with the rest of BODY)
                //   But putting them in H1 would make it look very big. Make H1s smaller by changing them to H2
                var mainContent = matches[3];
                var h1Count = (mainContent.match(/<H1>/ig) || []).length;
                
                if(h1Count == 0) {
                    
                    // There are no H1 - this is the default template. We will not display matches[2] (H1 section) because it is already displayed in ponHeadline
                    document.getElementById('ponHeadline').innerText = title;
                    document.getElementById('ponMainWindow').innerHTML = mainContent;
                } else {
                    
                    // there are multiple H1's; so headline content should be the first H1 only (otherwise it will be very long)
                    //  and our main content be in a smaller font H2
                    var firstH1Match = helpContent.match(/<H1>(.*?)<\/H1>/i);
                    if(firstH1Match.length >= 1) {
                        document.getElementById('ponHeadline').innerText = firstH1Match[1];
                    } else {
                        document.getElementById('ponHeadline').innerText = title;
                    }
                    
                    // Change H1 to H2 so that the section headings don't look too big
                    mainContent = mainContent.replace(/<H1>/ig, '<h2>');
                    mainContent = mainContent.replace(/<\/H1>/ig, '<\/h2>');
                    document.getElementById('ponMainWindow').innerHTML = mainContent;
                }
            }
            
        } else {
            // Could not find the title and H1 header; maybe the content is not the standard TTO PoN
            //  We will just render the full content as is
            document.getElementById('ponMainWindow').innerHTML = helpContent;
        }
    },
    
    customizeHelpContent : function () {
        
        // Customize the default look and feel of the help content such that it suits TTU requirements
        
        // First, handle the new PoN pages (Inquira PoN) whose default styles are defined in pon.css
        // The primary change is to modify the overflowY of the div id 'pon-answer-container' from 'scroll' to '' so that the content is not clipped vertically
        for(var i = 0; i < document.styleSheets.length; i++) {
            var stylesheet = document.styleSheets[i];
            if(stylesheet.href.indexOf('pon.css') > -1 ) {
                var cssRules = stylesheet.cssRules;
                for(var j = 0; j < cssRules.length; j++) {
                    var cssRule = cssRules[j];
                    // Customize the style for the main content div to change the overflow and reduce left/right margins
                    if(cssRule.selectorText == '#pon-answer-content') {
                        cssRule.style.overflowY = "";
                        // modify left margin and right PADDING (not margin since that is how it is defined in pon.css)
                        cssRule.style.marginLeft = "15px";
                        cssRule.style.paddingRight = "15px";
                    }
                    
                    // Customize the style for the title div to reduce left/right margins
                    if(cssRule.selectorText == '#pon-title-container') {
                        cssRule.style.marginLeft = "15px";
                        cssRule.style.marginRight = "15px";
                    }
                }
                break;
            }
        }

        // Next, customize the style for Mojo-based help screens (for eg: W-2 import)
        // Modify the display from none to block so that the header is displayed
        if (document.getElementById('ponHeader')) {
            document.getElementById('ponHeader').style.display='block';
        }
        if (document.getElementsByClassName('modal-body')){
            if(document.getElementsByClassName('modal-body').length > 0) {
                document.getElementsByClassName('modal-body')[0].style.display = 'block';
            }
        }
        
        // Hide the bottom bars (these are also hidden in stylesheet).
        if (document.getElementById('ponDragHandle')){
            document.getElementById('ponDragHandle').style.display='none';
        }
        if (document.getElementById('ponBottomController')){
            document.getElementById('ponBottomController').style.display = 'none';
        }
        
        // Override the top.hyperTo functions defined for <button class='ponHyperButton'>
        //  these come in to play when there are PoN links in MojoPlayer rendered as fallback of TTO Player
        //  (eg: Were You Married)
        var hrefTags = document.getElementsByClassName('ponHyperButton');
        if (hrefTags){
            for(var i = 0; i < hrefTags.length; i++) {
                
                var link = hrefTags[i];

                link.onclick = function(){
                    var matches = new RegExp("hyperTo\\('(.*)'\\).*").exec(this.href)
                    if(matches != null && matches.length > 0) {
                        window.location = 'ttu://externalLink?helpLinkId=' + encodeURIComponent(matches[1]);
                        return;
                    }
                    var matches = new RegExp("hyperToUrl\\('(.*)'\\).*").exec(link)
                    if(matches != null && matches.length > 0) {
                        window.location = 'ttu://externalLink?URL=' + encodeURIComponent(matches[1]);
                        return;
                    }
                }
            }
        }
    },

};
